==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_entities/workorder_001/IncidentTracking.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PATIENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STAFFINJURY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SECURITYINCIDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROPERTYDAMAGE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HAZARDOUSMATERIALSINCIDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FIRESAFETYINCIDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MEDICALEQUIPMENTINCIDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UTILITYSYSTEMINCIDENT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "patient",
    "staffinjury",
    "securityincident",
    "propertydamage",
    "hazardousmaterialsincident",
    "firesafetyincident",
    "medicalequipmentincident",
    "utilitysystemincident"
})
@XmlRootElement(name = "IncidentTracking")
public class IncidentTracking {

    @XmlElement(name = "PATIENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String patient;
    @XmlElement(name = "STAFFINJURY", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String staffinjury;
    @XmlElement(name = "SECURITYINCIDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String securityincident;
    @XmlElement(name = "PROPERTYDAMAGE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String propertydamage;
    @XmlElement(name = "HAZARDOUSMATERIALSINCIDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String hazardousmaterialsincident;
    @XmlElement(name = "FIRESAFETYINCIDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String firesafetyincident;
    @XmlElement(name = "MEDICALEQUIPMENTINCIDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String medicalequipmentincident;
    @XmlElement(name = "UTILITYSYSTEMINCIDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String utilitysystemincident;

    /**
     * Obtient la valeur de la propriété patient.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPATIENT() {
        return patient;
    }

    /**
     * Définit la valeur de la propriété patient.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPATIENT(String value) {
        this.patient = value;
    }

    /**
     * Obtient la valeur de la propriété staffinjury.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTAFFINJURY() {
        return staffinjury;
    }

    /**
     * Définit la valeur de la propriété staffinjury.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTAFFINJURY(String value) {
        this.staffinjury = value;
    }

    /**
     * Obtient la valeur de la propriété securityincident.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSECURITYINCIDENT() {
        return securityincident;
    }

    /**
     * Définit la valeur de la propriété securityincident.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSECURITYINCIDENT(String value) {
        this.securityincident = value;
    }

    /**
     * Obtient la valeur de la propriété propertydamage.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROPERTYDAMAGE() {
        return propertydamage;
    }

    /**
     * Définit la valeur de la propriété propertydamage.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROPERTYDAMAGE(String value) {
        this.propertydamage = value;
    }

    /**
     * Obtient la valeur de la propriété hazardousmaterialsincident.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHAZARDOUSMATERIALSINCIDENT() {
        return hazardousmaterialsincident;
    }

    /**
     * Définit la valeur de la propriété hazardousmaterialsincident.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHAZARDOUSMATERIALSINCIDENT(String value) {
        this.hazardousmaterialsincident = value;
    }

    /**
     * Obtient la valeur de la propriété firesafetyincident.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFIRESAFETYINCIDENT() {
        return firesafetyincident;
    }

    /**
     * Définit la valeur de la propriété firesafetyincident.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFIRESAFETYINCIDENT(String value) {
        this.firesafetyincident = value;
    }

    /**
     * Obtient la valeur de la propriété medicalequipmentincident.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMEDICALEQUIPMENTINCIDENT() {
        return medicalequipmentincident;
    }

    /**
     * Définit la valeur de la propriété medicalequipmentincident.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMEDICALEQUIPMENTINCIDENT(String value) {
        this.medicalequipmentincident = value;
    }

    /**
     * Obtient la valeur de la propriété utilitysystemincident.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUTILITYSYSTEMINCIDENT() {
        return utilitysystemincident;
    }

    /**
     * Définit la valeur de la propriété utilitysystemincident.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUTILITYSYSTEMINCIDENT(String value) {
        this.utilitysystemincident = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/workorder_001/IncidentTracking.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PATIENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STAFFINJURY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SECURITYINCIDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROPERTYDAMAGE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HAZARDOUSMATERIALSINCIDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FIRESAFETYINCIDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MEDICALEQUIPMENTINCIDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UTILITYSYSTEMINCIDENT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "patient",
    "staffinjury",
    "securityincident",
    "propertydamage",
    "hazardousmaterialsincident",
    "firesafetyincident",
    "medicalequipmentincident",
    "utilitysystemincident"
})
@XmlRootElement(name = "IncidentTracking")
public class IncidentTracking {

    @XmlElement(name = "PATIENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String patient;
    @XmlElement(name = "STAFFINJURY", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String staffinjury;
    @XmlElement(name = "SECURITYINCIDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String securityincident;
    @XmlElement(name = "PROPERTYDAMAGE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String propertydamage;
    @XmlElement(name = "HAZARDOUSMATERIALSINCIDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String hazardousmaterialsincident;
    @XmlElement(name = "FIRESAFETYINCIDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String firesafetyincident;
    @XmlElement(name = "MEDICALEQUIPMENTINCIDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String medicalequipmentincident;
    @XmlElement(name = "UTILITYSYSTEMINCIDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String utilitysystemincident;

    /**
     * Gets the value of the patient property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPATIENT() {
        return patient;
    }

    /**
     * Sets the value of the patient property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPATIENT(String value) {
        this.patient = value;
    }

    /**
     * Gets the value of the staffinjury property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTAFFINJURY() {
        return staffinjury;
    }

    /**
     * Sets the value of the staffinjury property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTAFFINJURY(String value) {
        this.staffinjury = value;
    }

    /**
     * Gets the value of the securityincident property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSECURITYINCIDENT() {
        return securityincident;
    }

    /**
     * Sets the value of the securityincident property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSECURITYINCIDENT(String value) {
        this.securityincident = value;
    }

    /**
     * Gets the value of the propertydamage property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROPERTYDAMAGE() {
        return propertydamage;
    }

    /**
     * Sets the value of the propertydamage property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROPERTYDAMAGE(String value) {
        this.propertydamage = value;
    }

    /**
     * Gets the value of the hazardousmaterialsincident property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHAZARDOUSMATERIALSINCIDENT() {
        return hazardousmaterialsincident;
    }

    /**
     * Sets the value of the hazardousmaterialsincident property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHAZARDOUSMATERIALSINCIDENT(String value) {
        this.hazardousmaterialsincident = value;
    }

    /**
     * Gets the value of the firesafetyincident property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFIRESAFETYINCIDENT() {
        return firesafetyincident;
    }

    /**
     * Sets the value of the firesafetyincident property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFIRESAFETYINCIDENT(String value) {
        this.firesafetyincident = value;
    }

    /**
     * Gets the value of the medicalequipmentincident property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMEDICALEQUIPMENTINCIDENT() {
        return medicalequipmentincident;
    }

    /**
     * Sets the value of the medicalequipmentincident property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMEDICALEQUIPMENTINCIDENT(String value) {
        this.medicalequipmentincident = value;
    }

    /**
     * Gets the value of the utilitysystemincident property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUTILITYSYSTEMINCIDENT() {
        return utilitysystemincident;
    }

    /**
     * Sets the value of the utilitysystemincident property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUTILITYSYSTEMINCIDENT(String value) {
        this.utilitysystemincident = value;
    }

}
